c
c	Program runs the subroutine iri_sm to obtain IRI13 densities
c	along an L-shell.
c
	subroutine iri_ps_bridge(rloc,al,alatr,amlt,itime,eq_iri_ps_trough,
     &		transh,alpha,ano,co,istat)
c
	real re,tot_delh,delh,r,amltrad
	parameter (re=6371.0,tot_delh=600.0/re,delh=5.0)
	parameter (r=260.0/re+1.0)
c	parameter (r=260.0/re+1.0,delr=delh/re)
	parameter (amltrad=3.1415927/12.0)
c
	real outf(11,100),oarr(35),alatr,along
	real dens,hs,dens_old,rf3
	real delrr,ahemisphere,refden
	real amlt,rf2,cosrl,rs,al,diff3,diff2,diff1
	real diff2sq,diff3sq,ro,transh,delhh,alpha,term1
	real eqh,ano,eq_iri_ps_trough,co,fract,rloc
	real dent
	integer itime(2)
	integer istat,icount,iflag

d	type *,'entering iri_ps_bridge',rloc,al,amlt,itime,eq_iri_ps_trough
	istat=0
	delrr=5.0/re
c !Trevor Garner found error assuming north only, now pass latitude
	ahemisphere=sign(1.0,alatr)
c  get height and densiy of the f2 peak
c	cosrl=amin1(sqrt(r/al),1.0)
c	alatr=acos(cosrl)  !Trevor Garner found error assuming north only, now pass lat
	along=amod((amlt+12.0),24.0)*amltrad
	call iri_sm(alatr,along,r,itime,outf,oarr)

	rf2=oarr(2)/re+1.0
	cosrl=amin1(sqrt(rs/al),1.0)
	alatr=acos(cosrl)*ahemisphere
	call iri_sm(alatr,along,rf2,itime,outf,oarr)

	rf3=oarr(2)/re+1.0
	cosrl=amin1(sqrt(rf3/al),1.0)
	alatr=acos(cosrl)*ahemisphere
	call iri_sm(alatr,along,rf3,itime,outf,oarr)

	rs=oarr(2)/re+1.0

c  If L-shell is at or below "r", the starting radial distance
c  for searching for the maximum negative slope above the f2 peak,
c  then the L-shell provided is exclusively an ionospheric issue
c  and we need to pass back parameters that will minimize the hassle
c  associated with the rest of the calculation for density, which
c  will necessarily exclude the bridge density anyway.

	if(rs.ge.al) then
	  istat=-1
d	  type *,'No bridge required, istat=-1 ',rs,al
	  return
	endif

c  This next "do while" section will search for the maximum negative
c  gradient in density along the al L-shell and above the f2 peak
c  If we do not find that maximum negative gradient before reaching
c  al, then we'll just report the ionospheric density should be used
c  through use of the istat=-1 variable.
10	continue
	diff3=1.0e30
	diff2=2.0e30

d	type *,'starting "while" in iri_ps_bridge',al,rs,delrr
	icount=0
	do while (diff3 .lt. diff2 .and. (rs+delrr).lt.al)

	  icount=icount+1

	  diff1=diff2
	  diff2=diff3
	  dens_old=outf(1,1)
	  rs=rs+delrr

	  cosrl=amin1(sqrt(rs/al),1.0)
	  alatr=acos(cosrl)*ahemisphere
	  call iri_sm(alatr,along,rs,itime,outf,oarr)
	  diff3=outf(1,1)-dens_old
d	  type *,'condition:',diff3,diff2,(rs+delrr),al
	end do

c  if have less than icount=3, then must repeat with smaller step
c  if we left the do-while due to reaching the equator then
c  skip the fits and just use IRI
	if((icount.lt.3).or.((rs+delrr).ge.al)) then
	  istat=-1
	  return
	endif

c  use parabolic interpolation to estimate radial distance of
c  maximum negative gradient in density along the field line,
c  given the last three samples of the gradient versus altitude
d	type *,'fit',icount,rs,diff1,diff2,diff3
	diff2sq=diff2**2
	diff3sq=diff3**2
	ro=(rs-delrr/2.0)-delrr*((diff3sq-diff2sq)/(diff3sq-
     &		2.0*diff2sq+diff1**2)+0.5)
	transh=(ro-1.0)*re

	rs=ro-delrr/2.0
	cosrl=amin1(sqrt(rs/al),1.0)
	alatr=acos(cosrl)*ahemisphere
	  call iri_sm(alatr,along,rs,itime,outf,oarr)
	dens_old=outf(1,1)
d	type *,'old=',(rs-1.0)*re,dens_old

	rs=ro+delrr/2.0
	hs=(rs-1.0)*re
	cosrl=amin1(sqrt(rs/al),1.0)
	alatr=acos(cosrl)*ahemisphere
	  call iri_sm(alatr,along,rs,itime,outf,oarr)
	dens=outf(1,1)
d	type *,'new=',hs,dens

	delhh=delrr*re
	alpha=-log(dens_old/dens)/log(1.0-delhh/hs)
	term1=hs**(-alpha)
	eqh=(al-1.0)*re
	ano=(dens-eq_iri_ps_trough)/(term1-eqh**(-alpha))
	co=dens-ano*term1
d	type *,'init=',alpha,ano,co

c  We cannot let co become too small, so if it is we have to put up with a
c  slope change in the topside ionosphere densities returned.  In that
c  case, we'll make alpha just enough larger to insure that the power-law
c  term is no more than 10% of the value of co at the equator.
c
	fract=0.1
	iflag=0
	if (ano*eqh**(-alpha)/eq_iri_ps_trough .gt. fract .and.
     &		rloc.gt.3.0) then
	  iflag=1
	  refden=eq_iri_ps_trough*fract
	  dent=(dens_old+dens)/2.0
	  alpha=-log(dent/(refden))/log(transh/eqh)
	  term1=eqh**(-alpha)
	  ano=(dent-eq_iri_ps_trough)/(transh**(-alpha)-term1)
	  co=eq_iri_ps_trough-ano*term1
	endif


d	type *,dens_old,dens,delh,hs
d	type *,'leaving iri_ps_bridge',alpha,ano,transh,co
	return
	end
