c
c This function determines the trough density in the equatorial
c plane in particles/cm^3.
c
c	written	dlg	07/14/99
c
c INPUT:
c	l    = L-shell (real*4)
c	amlt = solar magnetic local time in hours (real*4)
c	akp  = Global Kp index as a real number, e.g 1+=1.3 (real*4)
c
c OUTPUT:
c	ne_eq_trough = trough density in the equatorial plane
c					in cm-3 units (real*4)
c
	function ne_eq_trough(l,amlt,akp)
c
	real ne_eq_trough,l,amlt,akp
	real phitp,antp,damping_time,damping
	real dendamp,dengrow
	real switch0,switch1,switch2,switch3
	real down_time,del,center,diff,aminden,width,denmin
	real sdel,shift,switchon
c
c  compute MLT where trough density peaks assuming constant Kp
	phitp=0.145*akp**2-2.63*akp+21.86
c
c  assuming constant density increase of 0.56+-0.08 cm-3h-1 before phitp
c  and constant density decrease of -0.83+-0.15 cm-3h-1 after that and before
c  1 hour MLT, where the decrease is replaced by zero growth.  Growth begins
c  again at 3.5 hours MLT.  A minimum density of 0.18 cm-3 is used.
c  Transitions between growth rates are made over an hour or more, as shown below.
c
c  compute unsmoothed peak density at phitp
	antp=(phitp-3.5)*0.56
c  how long with it take to loose what was gained?
c    minimum loss rate required to get back to 0.18 cm-3 by 2.0 hours MLT
	damping_time=amin1(26.0-phitp,antp/0.83)
c  given the loss rate above as a minimum.
	damping=-antp/damping_time
	down_time=phitp+damping_time
	del=3.5-(down_time-24.0)
	center=3.5-del/2.0
	if(center.lt.0.0) center=24.0+center
	diff=amlt-center
	if(diff.lt.-12.0) diff=24.0+diff
	if(diff.gt.12.0) diff=diff-24.0
	aminden=0.18
c	width=25.0
	width=2.0*del
	denmin=aminden+diff**2/(del*width)
c
c  must deal with computation differently based on current mlt
	dengrow=0.56*(amlt-3.5)+aminden
	sdel=0.4
	shift=0.5
	switch1=switchon(amlt,3.5+shift,sdel)
	switch2=switchon(amlt,phitp,0.5)
	if(amlt.lt.8.0) then
	  dendamp=antp+damping*(amlt+24.0-phitp)
	  switch0=switchon(amlt,down_time-24.0-shift,sdel)
	  ne_eq_trough= denmin*switch0*(1.0-switch1) 
     &		+ dendamp*(1.0-switch0)
     &	           + dengrow*switch1*(1.0-switch2)
	else
	  dendamp=antp+damping*(amlt-phitp)
	  switch3=switchon(amlt,down_time-shift,sdel)
	  ne_eq_trough= denmin*switch3 + dengrow*switch1*(1.0-switch2)
     &	           + dendamp*switch2*(1.0-switch3)
	end if
c scale density from trough density at geosynchronous orbit
c to L-shell of interest "l" using a power law of -4.5 in L
	ne_eq_trough=ne_eq_trough*l**(-4.5)/2.0514092e-4
c	    =ne_trough*l**(-4.5)/6.6**(-4.5)
c
	return
	end

