c
c	This routine is used to isolate the plasmasphere, trough,
c	and associated ionosphere.  The program is written for use 
c	in calculating EUV luminocity through the plasmasphere.
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c	Input parameters:
c
c	itime	integer*4	dimensions=2
c		(1) = yeardoy, e.g. 2001093
c		(2) = miliseconds of day
c	r		real*4		dimension=1
c		geocentric radial distance in Re
c	al	real*4	dimensions=1
c		MacIlwain L-shell parameter (Dipole coordinates)
c	amlt	real*4		dimension=1
c		solar magnetic local time in hours
c	amlat	real*4		dimension=1
c		solar magnetic latitude in radians
c	akp		real*4		dimension=1
c		planetary Kp index
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc
c	Output parameters:
c	outn	real*4		dimensions=4
c			(1) = total electron density in 1/cm^3
c			(2) = total hydrogen density in 1/cm^3
c			(3) = total helium density in 1/cm^3
c			(4) = total oxygen density in 1/cm^3
ccccccccccccccccccccccccccccccccccccccccccccccccccccccccccccc

c
	subroutine ne_subauroral(r,al,alatr,amlt,akp,itime,outn)
	real outn(4),ne_iri_ps_trough,re,alcrit,altrans
	real den,r,al,alatr,amlt,akp,aheh,f107,switchon
	real aheight,alphaO,alphaHeP,alphaHe,no,rz12
	real ne,nh,nhe
	integer itime(2)
	common /irioutput/ rz12,f107,ne,nh,nhe,no
	data re/6371.0/

c	clat=cos(alatr)**2
c	if(clat.lt.1.0e-5) clat=1.0e-5
c	al=r/clat
	alcrit=9.0
	altrans=4.0
c	f107=150.0
c
c get total electron density
	den=ne_iri_ps_trough(r,al,alatr,amlt,akp,itime)/1.0e6
d	type *,'back from nr_iri_ps_trough',den

c compute He+ to H+ density ratio in the plasmasphere
	aHeH=10.0**(-1.541-0.176*r+8.557e-3*f107
     &		-1.458e-5*f107*f107)
c Helium concentration drops dramatically with transition to high latitudes
c and open field lines
d	type *,'intermediate aheh',aheh
	aHeH=aHeH*(1.0-switchon(al,alcrit,altrans))
c compute relative O+ density
d	type *,'aheh',aheh
	aheight=(r-1.0)*re
	alphaO=0.995/(1.0+(aheight-350.0)**2/281250.0)**3+0.005
d	type *,'alphaO',alphaO
c compute relative He+ concentration in the plasmasphere
	if(aHeH.ne.0.0) then
	  alphaHeP=(1.0-alphaO)/(1.0+1.0/aHeH)
	  alphaHe=amax1(0.0,alphaHeP*(1.0-exp(-(aheight-400.0)/600.0)))
	else
	  alphaHe=0.0
	end if
c compute densities of H+, He+, and O+
d	type *,'alphaHe',alphaHe
	outn(1)=den
	outn(3)=alphaHe*den
	outn(4)=alphaO*den
	outn(2)=outn(1)-outn(3)-outn(4)
c
	return
	end
